Clojure only.

duct.repl.datalog


connclj

(conn)

Get the database connection from the system map.

Get the database connection from the system map.
sourceraw docstring

dbclj

(db)

Get a queryable database from the system database connection.

Get a queryable database from the system database connection.
sourceraw docstring

qclj

(q query & inputs)

Run a datalog query on the system database. The database will be automatically added as the first input.

Run a datalog query on the system database. The database will be
automatically added as the first input.
sourceraw docstring

transactclj

(transact tx-data)

Apply a transaction to a database via the system database connection.

Apply a transaction to a database via the system database connection.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries